@@ -52,10 +52,7 @@ check_installs <- function(x) {
 check_label <- function(txt, ..., call = caller_env()) {
   check_dots_empty()
   if (is.null(txt)) {
-    rlang::abort(
-      "`label` should be a single named character string or NULL.",
-      call = call
-    )
+    return(invisible(txt))
   }
   if (!is.character(txt) || length(txt) > 1) {
     rlang::abort(
@@ -72,14 +69,6 @@ check_label <- function(txt, ..., call = caller_env()) {
   invisible(txt)
 }
 
-check_finalize <- function(x, ..., call = caller_env()) {
-  check_dots_empty()
-  if (!is.null(x) & !is.function(x)) {
-    rlang::abort("`finalize` should be NULL or a function.", call = call)
-  }
-  invisible(x)
-}
-
 check_range <- function(x, type, trans, ..., call = caller_env()) {
   check_dots_empty()
   if (!is.null(trans)) {
@@ -118,3 +107,38 @@ check_range <- function(x, type, trans, ..., call = caller_env()) {
   }
   invisible(x0)
 }
+
+check_values_quant <- function(x, ..., call = caller_env()) {
+  check_dots_empty()
+
+  if (is.null(x)) {
+    return(invisible(x))
+  }
+
+  if (!is.numeric(x)) {
+    rlang::abort("`values` must be numeric.", call = call)
+  }
+  if (anyNA(x)) {
+    rlang::abort("`values` can't be `NA`.", call = call)
+  }
+  if (length(x) == 0) {
+    rlang::abort("`values` can't be empty.", call = call)
+  }
+
+  invisible(x)
+}
+
+check_inclusive <- function(x, ..., call = caller_env()) {
+  check_dots_empty()
+  if (length(x) != 2) {
+    rlang::abort("`inclusive` must have upper and lower values.", call = call)
+  }
+  if (any(is.na(x))) {
+    rlang::abort("`inclusive` must be non-missing.", call = call)
+  }
+  if (!is.logical(x)) {
+    rlang::abort("`inclusive` should be logical", call = call)
+  }
+  invisible(x)
+}
+
